@@ -57,9 +57,8 @@ class Config(YamlDataClassConfig):
         of the performed transformations.
 
         """
-        jvm_=self.spark_config._jvm
         for trans in self.transformations:
-            df=trans.transform(df=df, jvm=jvm_)
+            df=trans.transform(df=df)
         return df
 
     def __get_outputs__(self, df):
