@@ -35,12 +35,12 @@ class Csv(Source):
     type = "Csv"
     csv_path: str = None
     delimiter: str = ';'
-    sep = None
+    header: bool = True
+    sep: str = None
     encoding = None
     quote = None
     escape = None
     comment = None
-    header = None
     inferSchema = None
     ignoreLeadingWhiteSpace = None
     ignoreTrailingWhiteSpace = None
@@ -62,7 +62,8 @@ class Csv(Source):
     emptyValue = None
 
     def apply(self, spark_session):
-        return spark_session.read.option("delimiter", self.delimiter).csv(
+        return spark_session.read\
+            .option("delimiter", self.delimiter).csv(
             path=self.csv_path,
             sep=self.delimiter,
             encoding=self.encoding,
